;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Loading this file installs CG/JS.
;; Please see readme.txt for more information
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(in-package :user)

(eval-when (compile eval load)
  (require :shell)
  (use-package :excl.shell))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; validate files

(let ((platform-file
       (directory
	(merge-pathnames
	 "PLATFORM-*"
	 (path-pathname *load-pathname*)))))
  (or platform-file
      (error "Could not find the PLATFORM file."))
  
  (when (> (length platform-file) 1)
    (error "There is more than one PLATFORM file: ~a." platform-file))
  (setq platform-file (car platform-file))
  
  (or (=~ "^PLATFORM-(.*)" (file-namestring platform-file))
      (error "Cannot parse the PLATFORM file."))
  
  (let ((expected-platform $1)
	(current-platform
	 (format nil "~a~a" (symbol-name sys::.os.) #+smp "smp" #-smp "")))
    (or (string-equal expected-platform current-platform)
	(error
	 "The current platform (~a) does not match the downloaded version (~a)."
	 current-platform expected-platform)))
  ;; We are on the correct platform, fall through...
  )

;; HTML files needed for the operation of CG/JS
;; (this variable's value is generated by build_cgjs.sh)
(defvar *html-files* '("cgjs.html" "ssl-not-found.html" "browser-not-supported.html" ))

(defvar *extra-files*)
(setq *extra-files* nil)

(dolist (file *html-files*)
  (setq file (merge-pathnames file *load-pathname*))
  (or (probe-file file)
      (error "~a does not exist." file))
  (push file *extra-files*))
;; All *html-files* exist...

;; These two are directories but the pathname is specified as
;; a file, so merging works below.
(defvar *cg2js-directory* (merge-pathnames "code.cg2js" *load-pathname*))
(defvar *idejs-directory* (merge-pathnames "code.idejs" *load-pathname*))

(dolist (d (list *cg2js-directory* *idejs-directory*))
  (or (probe-file d)
      (error "~a does not exist." d)))

;; MD5 checksums of the incoming files
;; (this variable's value is generated by build_cgjs.sh)
(defvar *checksums* 
'(
(#x564b8b75c5c14f60b7b79b63bb6780a0 . "./code.cg2js/cg-status-bar.fasl")
(#xccac8ace744727f211703ae0a1f3896c . "./code.cg2js/cg-hotspot.fasl")
(#x5cd457a17f87f6cf9cdfa7ed08870e82 . "./code.cg2js/cg-toolbar.fasl")
(#x8f5e5fca0acd7906c8a1052af2d777d7 . "./code.cg2js/cg-clipboard-stack.fasl")
(#xf0f76619c4372b51a265f9daa212f0cc . "./code.cg2js/cg-tooltip.fasl")
(#x949665fd168357362377a13ad65cb944 . "./code.cg2js/cg-calendar.fasl")
(#xf1ba8c31ee26ad6629f85bf4a7b2568f . "./code.cg2js/cg-item-list.fasl")
(#x9965dd68379b034b14361478305c20a7 . "./code.cg2js/cg-bitmap-stream.fasl")
(#xea98a98a89a673fe7424331995f79641 . "./code.cg2js/cg-trackbar.fasl")
(#x7a0dd83831ac510d56e88153e2d08b3b . "./code.cg2js/cg-class-grid.fasl")
(#x729b268bdd82df451550bbc421ad9658 . "./code.cg2js/cg-dialog-item.fasl")
(#xa678e150d716d409cbfbbcef1e147c1b . "./code.cg2js/cg-comtab.fasl")
(#x2ba5fab4e73df6bda69e2b391733f63b . "./code.cg2js/cg-lisp-text.fasl")
(#xea6e34e9fcf8b86944626bbf126e925e . "./code.cg2js/cg-rich-edit-pane.fasl")
(#x4fb98573dea040a2adc803133a1dca7d . "./code.cg2js/cg-button.fasl")
(#xfd12c9a9bf0dc793b44ad5e9999edb6f . "./code.cg2js/cg-printing.fasl")
(#x051e25b3c8b35c464fe3c0699d23a092 . "./code.cg2js/cg-pixmap-printing.fasl")
(#xacd5083199ec064ead99c508ee82329b . "./code.cg2js/cg-multi-picture-button-tooltip.fasl")
(#x5833397ffd0b5b0793f0547a59c76d2e . "./code.cg2js/cg-pixmap-widget.fasl")
(#xe228e0d5535d7d70cf0f26ab6e339e0e . "./code.cg2js/cg-selected-object.fasl")
(#x9c4cf7f5f2ad532ba5b4412d5fbed8a8 . "./code.cg2js/cg-text-or-combo.fasl")
(#x5864492254e7148eb0509082eefbbeab . "./code.cg2js/cg-graphics-context.fasl")
(#xb98840e4c2339009ca287aa3eecda55d . "./code.cg2js/cg-edit-in-place.fasl")
(#xfe817ea96a2c878c5fbe22dbc9e85149 . "./code.cg2js/cg-string-dialog.fasl")
(#xa809a24c7b9410f9668de57a9759a5cf . "./code.cg2js/cg-list-view.fasl")
(#xc34435e3e3880426093809895e93ed23 . "./code.cg2js/cg-intersect.fasl")
(#xd8424f4d88f45e2c1effc5e0e5679e85 . "./code.cg2js/cg-text-widget.fasl")
(#xbed4b284d13d01ea47a2dc0270deea47 . "./code.cg2js/cg-directory-dialog.fasl")
(#x9995d8af9adce53f40fad93251e45c72 . "./code.cg2js/cg-file-dialog.fasl")
(#x871c7bc8b992a36194bc3b82842ba155 . "./code.cg2js/cg-dde-utils.fasl")
(#x3679d6d504f979f885b023c70b2912d6 . "./code.cg2js/cg-nodes.fasl")
(#x59ae09909e3d1d77bde1666181fa2a3f . "./code.cg2js/cg-text-edit-pane-mark.fasl")
(#x143f373ab65265a814eb972acbfeeb2f . "./code.cg2js/cg-up-down-control.fasl")
(#x50dab614625ccaaa5d151d20805c8f8b . "./code.cg2js/cg-get-position.fasl")
(#x09189ab4adedd808ce8ef0df868ed917 . "./code.cg2js/cg-toggling-widget.fasl")
(#xb678171be33b18bf48d73188c938d9d4 . "./code.cg2js/cg-acache.fasl")
(#xb7fb9a2cdebce5bd68c7f9e2eaf98600 . "./code.cg2js/cg-outline-drag-and-drop.fasl")
(#x7b60d037dbbe2d6e7dd595472c4f08c8 . "./code.cg2js/cg-base.fasl")
(#xa690f3ece86db15d1263f379eed177f6 . "./code.cg2js/cg-drag-and-drop.fasl")
(#x32fac7e019b8b84dd87343dac759c01b . "./code.cg2js/cg-find-string-dialog.fasl")
(#x99a585a2c6c9da877619aefec2d642b4 . "./code.cg2js/cg-property.fasl")
(#x155cf087a23d1f48e7c4421aa00e7455 . "./code.cg2js/cg-editable-text.fasl")
(#x20328d1a032392873ee9316a6d3069f8 . "./code.cg2js/cg-lamp.fasl")
(#x7bd8b42205dc532900559fedf231a6df . "./code.cg2js/cg-progress-indicator.fasl")
(#xd00181459c37b6ecc4d9081a78d20808 . "./code.cg2js/cg-chart-widget.fasl")
(#x33975285cfc4f701cabacd16ad0f1a02 . "./code.cg2js/cg-common-control.fasl")
(#xf310dd8327804f33203fe3268dc0bff6 . "./code.cg2js/cg-font-dialog.fasl")
(#x9d6528eb5cda43bf03646f84ec67c02f . "./code.cg2js/cg-gesture-emulation.fasl")
(#x1c5fa8700f1bd83f96563e17af88a13e . "./code.cg2js/cg-pixmap-file-io.fasl")
(#xf3d0ed88caf39332b89c6aae35b33f06 . "./code.cg2js/cg-os-window.fasl")
(#xf2326c4b99763a0890c8820fe32a0ced . "./code.cg2js/cg-multi-line-lisp-text.fasl")
(#xd4c9e9c3d9dfae2fdb4ab66050cb8406 . "./code.cg2js/cg-pixmap.fasl")
(#x395c997ad34a230b6c6100441792811e . "./code.cg2js/cg-chart-or-plot.fasl")
(#x29a89edac75fb1b1aebaf55f1193481f . "./code.cg2js/cg-scroll-bar-mixin.fasl")
(#x6708ee54c31129130d489bcd7314bdf2 . "./code.cg2js/cg-scaling-stream.fasl")
(#xa11003281cc15a7cd914cdf078803a1a . "./code.cg2js/cg-grid-widget-drag-and-drop.fasl")
(#xc90d12bfe99b5d01a352c306a350762f . "./code.cg2js/cg-picture-widget-palette.fasl")
(#x232d98fbc2ea23280917168b0ab1bd9d . "./code.cg2js/cg-timer.fasl")
(#xaad3c4c51b5d1863acee4e1fde8ec62f . "./code.cg2js/cg-scroll-bar.fasl")
(#x1f030f67c39b6ed5231ce511a11ba439 . "./code.cg2js/cg-caret.fasl")
(#xea867f015fc1559044edcf2c171d0ecc . "./code.cg2js/cg-template-string.fasl")
(#x9df310f70095e8e7aa6c6ea46bc801b9 . "./code.cg2js/cg-multi-picture-button-drag-and-drop.fasl")
(#x8beae286cd5fe4f6122b41eca8abc3a3 . "./code.cg2js/cg-directory-dialog-os.fasl")
(#x25cee6751523e8ebd84358d3b4283f2a . "./code.cg2js/cg-rich-edit.fasl")
(#x2688cf3dbb3e3cc7098234ae57a95e55 . "./code.cg2js/cg-combo-box.fasl")
(#x46539554067e1c975813d48ca5cc1946 . "./code.cg2js/cg-text-edit-pane.fasl")
(#xc693aa72c178e96a8bb478848cb7d835 . "./code.cg2js/cg-multi-picture-button.fasl")
(#xe17a32a4bb687abdc1afada94fed36d7 . "./code.cg2js/cg-menu-tooltip.fasl")
(#xc540d6ef66295919d8bddc86d902bb35 . "./code.cg2js/cg-scrolling-static-text.fasl")
(#x1b9486dbe7f2d0563fceb81285bf904b . "./code.cg2js/cg-outline.fasl")
(#xdffe52471fc3dc502f2d3f448da88372 . "./code.cg2js/cg-class-support.fasl")
(#x84bec4835027b8d929f8511f42779309 . "./code.cg2js/cg-header-control.fasl")
(#xf043d1a39614ab3be1ba08508b70b188 . "./code.cg2js/cg-lettered-menu.fasl")
(#x0d913f7907197f5d5f1ec7ff758b9ff1 . "./code.cg2js/cg-cursor-pixmap.fasl")
(#xac27c3552eaabfed33188decffd134d7 . "./code.cg2js/cg-fill-texture.fasl")
(#xa032de97d25a4f65edc6be7ef33bfad8 . "./code.cg2js/cg-lisp-widget.fasl")
(#x487adf38db0a89e77a4017099f25ec03 . "./code.cg2js/cg-keyboard-shortcuts.fasl")
(#x506d1a1a7b7602235626f7495391b7fd . "./code.cg2js/cg-clipboard.fasl")
(#x0706668ef97fe50ea66859434f668dd7 . "./code.cg2js/cg-wrap-string.fasl")
(#x2e45615fdd76bf235e9b43e5694ab15e . "./code.cg2js/cg-os-widget.fasl")
(#x70abcafaa1e364ba9de3a67f4e8836cb . "./code.cg2js/cg-check-box.fasl")
(#x0af24673b4aef30e4e14096990cdde77 . "./code.cg2js/cg-choice-list.fasl")
(#x626bc04401a89bb0b52ec3bafde8a7b3 . "./code.cg2js/cg-layout.fasl")
(#x2a04694591496364777ac3392efbd667 . "./code.cg2js/cg-group-box.fasl")
(#x6147527806860f70b6d4115712ff611a . "./code.cg2js/cg-bitmap-pane-clipboard.fasl")
(#xb7416225f570d499f4dbfbb934e303ac . "./code.cg2js/cg-radio-button.fasl")
(#x53a88e5a64eaac7d68ccece28273279a . "./code.cg2js/cg-tab-control.fasl")
(#xc065d3a8eebd79b49f343dc55477f175 . "./code.cg2js/cg.fasl")
(#xfd1a460db12232793ba2db1db4411483 . "./code.cg2js/cg-drawable-clipboard.fasl")
(#xe628a4a2395f9ebd34054ffd313787a0 . "./code.cg2js/cg-dropping-outline.fasl")
(#xe2819f35a608127f87aa5cb824f11904 . "./code.cg2js/cg-get-pixmap.fasl")
(#xec41e522c47f05ea34b00af49d43f5c2 . "./code.cg2js/cg-grid-widget.fasl")
(#x04bd3ce3dcf162a448f19947313bd6b1 . "./code.cg2js/cg-utility-dialog.fasl")
(#x41f21c88c5844991afe9d0ee2b1ccc15 . "./code.cg2js/cg-static-text.fasl")
(#x00affd37fb1413f236769441131b68b1 . "./code.cg2js/cg-class-slot-grid.fasl")
(#x1c4a86dd250de382b488ebf347e322b7 . "./code.cg2js/cg-object-editor-layout.fasl")
(#x4138a7a468aa7fe7699296b3f92bda3e . "./code.cg2js/cg-drag-and-drop-image.fasl")
(#xa72ce7c6f4b45132f6591d342acd6f6a . "./code.cg2js/cg-bitmap-pane.fasl")
(#x58981bc2258f7946b96a03742c49fa3e . "./code.cg2js/cg-plot-widget.fasl")
(#xc12f4d3e2bb719527cabf8b7d396ca88 . "./code.cg2js/cg-color-dialog.fasl")
(#x9c49cca7152a4a02ac01d52e94e9c15f . "./code.cg2js/cg-icon-pixmap.fasl")
(#x81166bbcda52860bd79771485548d9ab . "./code.cg2js/cg-icon.fasl")
(#x4e7e659b847481e95789ddea9e72e642 . "./code.cg2js/cg-dev.fasl")
(#x5da20660fedf27127b6e13f0d6785e73 . "./code.cg2js/cg-choose-printer.fasl")
(#x44c88f4e8f471b20f2652e6e2cd095bf . "./code.cg2js/cg-intersect-posbox.fasl")
(#x50d282be0892a2f8aa328f728cc04c94 . "./code.cg2js/cg-menu.fasl")
(#x6064857048e4c4aebd8312687a7896a1 . "./code.cg2js/cg-yes-no-list.fasl")
(#x6183774ba6936641e88339550e2017ec . "./code.cg2js/cg-palette.fasl")
(#x79b4759d4de935aabdd6785d6660be6c . "./code.cg2js/cg-outline-edit-in-place.fasl")
(#xb2654580a99a39116e7c79055f29c368 . "./code.cg2js/cg-message-dialog.fasl")
(#x6d8655e1d5b6836eae662cc9cc5bf562 . "./code.cg2js/cg-shortcut-menu.fasl")
(#xb8ee4aae5909f4e32607c71aff95e96c . "./code.cg2js/cg-rich-edit-pane-clipboard.fasl")
(#x3d453f34b39205fbcc5c117f071dce08 . "./code.cg2js/cg-split-bar.fasl")
(#xbdffb2c433d37b0812350601aac1cfc7 . "./code.cg2js/cg-multi-line-editable-text.fasl")
(#x5464cd1b954eb4c5edd25907eba5dec2 . "./code.cg2js/cg-web-browser.fasl")
(#xa81cd6ca26feb588bb7a9d15f440c6de . "./code.cg2js/cg-project-window.fasl")
(#x66b225433490c40b711f0d765800bb20 . "./code.cg2js/cg-picture-widget.fasl")
(#x7e248e9d785f6472878dfa77c92a5dab . "./code.cg2js/cg-pixmap-rotate.fasl")
(#xb1792e1653d4d3ea1acb71219504c3f5 . "./code.cg2js/cg-object-editor.fasl")
(#xc5edd2ae87af7992e235ca896fe13f2b . "./code.cg2js/cg-rich-edit-pane-printing.fasl")
(#x58943e98fc7b7aea04f0f094af82dc03 . "./code.cg2js/cg-paren-matching.fasl")
(#x5a1a249a79706c94c645353919304534 . "./code.cg2js/cg-sample-file-menu.fasl")
(#x2b103a8b7bf971692121a7a998ba89f6 . "./code.cg2js/cg-drawable.fasl")
(#x3268f40fe04db5085157af581863b899 . "./code.cg2js/cg-text-edit-pane-file-io.fasl")
(#x0607ff1b78e9e100a11c3cb56bb9d08e . "./code.cg2js/cg-html-widget.fasl")
(#x5c3981534fa4ab482509babe7e13e2fd . "./code.cg2js/cg-curve.fasl")
(#x6e56f75f4447aa9a78c9c278db75ca26 . "./code.cg2js/cg-yes-no-string.fasl")
(#xbfc5801ebc3bef2297378938813b885d . "./code.cg2js/cg-lisp-edit-pane.fasl")
(#x7ee5df7d4666c743d4f007629c63dc8a . "./code.cg2js/cg-html-dialog.fasl")
(#xbcef0caadf36cf2c75eb006c5cc60668 . "./code.cg2js/cg-clipboard-pixmap.fasl")
(#x55f3c912d8b3a72d056bb2de5cd4600f . "./code.cg2js/cg-tray.fasl")
(#x3bebb81c7065635a17523f3ac8340661 . "./code.idejs/ide-apropos.fasl")
(#x892dbc00c71120b1f413e4394f346b12 . "./code.idejs/ide-window-list.fasl")
(#xafc20138926cd6cd36e6642109f664c4 . "./code.idejs/ide-class-browser.fasl")
(#x70e249984ffa4c906417f61860c9e319 . "./code.idejs/ide-base.fasl")
(#x2897e75c8c1894b6c0b1a40bdb21a056 . "./code.idejs/ide-process-browser.fasl")
(#x71f17ccde7d1883914a77d07cafec18a . "./code.idejs/ide-acache.fasl")
(#x385d776b973d67bd664e238781d59296 . "./code.idejs/ide-navigator.fasl")
(#xe283d76b3cdf347350b222ece976544a . "./code.idejs/ide-trace.fasl")
(#xe5d19caf4516d9cdd7f0cdc53f1e155c . "./code.idejs/ide-project.fasl")
(#x1433e2cbae028aa2ba4740c758db638e . "./code.idejs/ide-patch-dialog.fasl")
(#xeb5e951c732636089a44ed66f00f7734 . "./code.idejs/ide-grapher.fasl")
(#xc07907b99d8c5bb0e680b76ba7eba052 . "./code.idejs/ide-dev.fasl")
(#xb0d54eb7e911f24b7044524a17b2c757 . "./code.idejs/ide-keyshort.fasl")
(#xa78da95db308b1bbe4fd366199c90040 . "./code.idejs/ide-editor.fasl")
(#xee080f26e8129085115bab8a0daf6a78 . "./code.idejs/ide-inspector.fasl")
(#xe007a3fd71d629e4ebe9bf8bcca7eb8a . "./code.idejs/ide.fasl")
(#x93da5d330509e836b5caaf2890546532 . "./code.idejs/ide-clipboard.fasl")
(#x899bfd1a4d157b331de9606c1df30315 . "./code.idejs/ide-find-definitions.fasl")
(#xb45285175b1bb094b6ac8716acf09bef . "./code.idejs/ide-form.fasl")
(#xf3d1b55f9f73aa78062e0c6fee27746c . "./code.idejs/ide-intro.fasl")
(#x909caebb8612036314cbce545fb0b924 . "./code.idejs/ide-find-in-files.fasl")
(#xffb34683b35925f33f500019b010004f . "./code.idejs/ide-package-list.fasl")
(#x9b9036447dd0adf2b7769c1f7071f39c . "./code.idejs/ide-class-grapher.fasl")
(#x785b009207cd19fe54c93fc535e484ec . "./cgjs.html")
(#x34779e5d4bbb71d45bf63f88fac54100 . "./ssl-not-found.html")
(#x90c6d2a65504d45266ad9fa3a49be2f9 . "./browser-not-supported.html"))
 )

(let ((files-ok
       (dolist (checksum *checksums* t)
	 (when (/= (car checksum)
		   (md5-file
		    (merge-pathnames (cdr checksum) *load-pathname*)))
	   (return nil)))))
  (cond
   ((not files-ok)
    (error "The extracted files failed the checksum test.  ~
Please download and/or extract again."))
   (t
    (format t "Checksums on files are OK...~%"))))

;; We have validated all the files are there...

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; check for needed patches

(eval-when (compile eval load) (require :build))

(defvar *required-patches* '(#+macosx ("build" . 3)))

(dolist (required-patch *required-patches*)
  (let ((existing-patch (assoc (car required-patch)
			    (cdr (assoc :system sys::*patches*))
			    :test #'string=)))
    (when (null existing-patch)
      (error "Could not find patch info for the ~s module."
	     (car required-patch)))
    (when (not (>= (second existing-patch) (cdr required-patch)))
      ;; The build patch number is NOT >= to the one we require
      (error "~
Expected version ~d of ~s but have version ~d.  Please update ~
your lisp with update.~a and then do the CG/JS installation again."
	     (cdr required-patch) (car required-patch)
	     (second existing-patch)
	     #+mswindows "exe"
	     #-mswindows "sh"))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; copy files

(defun copy (source dest)
  (cond
   ((file-directory-p source)
    (format t "Copy directory ~a~%" (enough-namestring source))
    (copy-directory source dest :quiet t))
   (t
    (format t "Copy file ~a~%" (enough-namestring source))
    (sys:copy-file source dest :verbose nil))))

(defvar *sys* (translate-logical-pathname (pathname "sys:")))

(cond
 ((excl::pathname-equalp (truename *sys*)
			 (path-pathname *load-truename*))
  (format t "Files are already in place, no copying requiring.~%"))
 (t ;; copy files, replacing them with new ones if they already exist
  (let (dest)
    (dolist (from *extra-files*)
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      (when (probe-file dest) (delete-file dest))
      (copy from dest))
    
    (dolist (from (list *cg2js-directory* *idejs-directory*))
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      ;; now make it a directory pathname
      (setq dest (pathname-as-directory dest))

      (when (probe-file dest) (delete-directory-and-files dest))
      (copy (pathname-as-directory from) dest)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; update develenv.cl to load CG/JS before the original version of CG

(defvar *setup-cgjs-loading* "sys:setup-cgjs-loading.cl")

;; Because users might use an ANSI lisp to install, have to make sure
;; the resulting file can be loaded into an ANSI and Modern lisp.
(with-open-file (s *setup-cgjs-loading* :direction :output
		 :if-exists :supersede)
  (format s "~
;; This file was created by install-cgjs.cl.
;; Please do not edit it.

")
  (dolist (dir (list "code.cg2js/" "code.idejs/"))
    (format s "
(let ((path (make-pathname
	     :type \"fasl\"
	     :directory (pathname-directory
			 (merge-pathnames
			  ~s
			  (translate-logical-pathname \"sys:\"))))))
  (format t \";; *require-search-list*: adding: ~~s~%\" path)
  (push path sys:*require-search-list*))

"
	    dir)))

(defvar *develenv.cl* (pathname "sys:develenv.cl"))

(when (not (probe-file *develenv.cl*))
  (setf (file-contents *develenv.cl*)
    ";; This file is loaded before images are rebuilt with update.sh/update.exe

"))

(let ((contents (file-contents *develenv.cl*)))
  (cond
   ((match-re
     (format nil "^#\\|\\|# \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl already correctly loads CG/JS.~%"))
   ((match-re
     (format nil "^#\\+ignore \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl: CG/JS disabled; will enable.~%")
    (setf (file-contents *develenv.cl*)
      (replace-re  contents
		  (format nil "^#\\+ignore *\\(load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  (format nil "#||# (load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  :multiple-lines t
		  :count 1)))
   (t
    (format t "develenv.cl: adding CG/JS initialization.~%")
    (setf (file-contents *develenv.cl*)
      (concatenate 'simple-string
	contents
	(format nil "~

;; To disable the use of CG/JS and go back to the originally released
;; (and possibly patched) version of CG/IDE, change the #||# to
;; #+ignore on the following line and the rebuild images by running
;; update.sh or update.exe, depending on your platform:
#||# (load \"sys:~a\")~%~%"
		(file-namestring *setup-cgjs-loading*)))))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; success!

(let ((msg (format nil "~
CG/JS installation successful!

NOTE: to use CG/JS you must rebuild images by running 'update.~a'
      in the Allegro CL directory (~a)."
		   #+mswindows "exe"
		   #-mswindows "sh"
		   *sys*)))
  #-mswindows (format t "~&~%~a~%" msg)
  #+mswindows (excl::internal-message-box msg "CG/JS Installation" :type :ok))
